# Security Policy

## Supported Versions

Please check the latest version of `pbir-utils` on PyPI or GitHub. We primarily support the latest release.

| Version | Supported          |
| ------- | ------------------ |
| Latest  | :white_check_mark: |
| Older   | :x:                |

## Reporting a Vulnerability

We take the security of `pbir-utils` seriously. If you believe you have found a security vulnerability, please report it to us as described below.

**Please do not report security vulnerabilities through public GitHub issues.**

### How to Report

If you believe you have found a security vulnerability, please Report it via the "Security" tab on the GitHub repository or send an email to the project maintainers (if public contact info is available).

You should receive a response within 48 hours. If for some reason you do not, please follow up via email to ensure we received your original message.
